#!/usr/bin/python3

import setuptools

setuptools.setup(name="pig",
                 version="0.1.1",
                 description="Phoenix Interfaces for Gadgets",
                 url="https://github.com/erikperillo/pig",
                 author="Erik Perillo",
                 author_email="erik.perillo@gmail.com",
                 license="GPL",
                 packages=["pig"],
                 classifiers=["Programming Language :: Python :: 3"])
